Module editor

Module editor 

The main control flow and functionality of the ad editor.

Structs

Editor
The main editor state.
MiniBufferState

Enums

Action
Supported actions for interacting with the editor state
Click
Transient state that we hold to track the last mouse click we saw while we wait for it to be released or if the buffer changes.
EditorMode
The mode that the Editor will run in following a call to Editor::run.