pub enum Addr {
Explicit(Dot),
Simple(SimpleAddr),
Compound(SimpleAddr, SimpleAddr),
}Expand description
An Addr can be evaluated by a Buffer to produce a valid Dot for using in future editing
actions. The Explicit variant is used to handle internal operations that need to provide a
Addr (as opposed to parsed user input) where we already have a fully evaluated Dot.
Variants
Implementations