pub enum AddrBase {
}Expand description
Primitives for building out addresses.
Line and column indices are 1-based to match the editor line numbering and common output formats from popular compilers and other command line tooling. Internally these indices are converted to be 0-based to match the internal representation of ad’s Dot.
Variants
Current
.
CurrentLine
-+ | +-
Bol
Eol
Bof
0
Eof
$
Line(usize)
n
RelativeLine(isize)
-/+n
Char(usize)
#n
RelativeChar(isize)
-/+#n
LineAndColumn(usize, usize)
n:m
Regex(Regex)
/re/ or +/re/
RegexBack(RevRegex)
-/re/