PlumbingMessage

Struct PlumbingMessage 

pub struct PlumbingMessage {
    pub src: Option<String>,
    pub dst: Option<String>,
    pub wdir: Option<String>,
    pub cur: usize,
    pub attrs: BTreeMap<String, String>,
    pub data: String,
}
The deserialized form of a plumbing message sent by a client.

Fields

src: Option<String>

The application or service generating the message

dst: Option<String>

The destination “port” for the message

wdir: Option<String>

The working directory (used when data is a filename)

cur: usize

The offset within ‘data’ where the user’s cursor currently lies (default=0). If a rule specifies a ‘narrows-to’ rule it will be used to narrow initial data to only include the specified cursor, otherwise the match will be rejected.

attrs: BTreeMap<String, String>

Name=value pairs. Must not contain newlines

data: String

The string content of the message itself