pub struct Match { /* private fields */ }Expand description
The match location of a Regex against a given input.
The sub-match indices are relative to the input used to run the original match.
Implementations
Sourceimpl Match
impl Match
Sourcepub fn match_text<'a, H>(&self, haystack: &'a H) -> Cow<'a, str>where
H: Haystack,
pub fn match_text<'a, H>(&self, haystack: &'a H) -> Cow<'a, str>where
H: Haystack,
Extract this match from the given haystack
Sourcepub fn submatch_text<'a, H>(
&self,
n: usize,
haystack: &'a H,
) -> Option<Cow<'a, str>>where
H: Haystack,
pub fn submatch_text<'a, H>(
&self,
n: usize,
haystack: &'a H,
) -> Option<Cow<'a, str>>where
H: Haystack,
Extract the given submatch by index if it exists
Sourcepub fn submatch_text_by_name<'a, H>(
&self,
name: &str,
haystack: &'a H,
) -> Option<Cow<'a, str>>where
H: Haystack,
pub fn submatch_text_by_name<'a, H>(
&self,
name: &str,
haystack: &'a H,
) -> Option<Cow<'a, str>>where
H: Haystack,
Extract the given submatch by name if it exists
Sourcepub fn named_matches(&self) -> Vec<&str>
pub fn named_matches(&self) -> Vec<&str>
The names of each submatch
pub fn iter_locs(&self) -> impl Iterator<Item = Option<(usize, usize)>>