pub enum QueryResult<'a, V> {
Val(&'a V),
Partial,
Missing,
}Expand description
The result of querying a Trie for a particular Key.
Variants
Val(&'a V)
A leaf value associated with the key used in the query
Partial
The key used to query is a prefix to multiple values
Missing
The key does not exist within the Trie