Trie

Struct Trie 

pub struct Trie<K, V>
where K: Clone + PartialEq + Ord, V: Clone,
{ /* private fields */ }
A singly initialised Trie mapping key sequences to a value.

It is not permitted for values to be mapped to a key that is a prefix of another key also existing in the same Trie.

There are convenience methods provided for Trie<char, V> for when &str values are used as keys.

Implementations

Source

impl<K, V> Trie<K, V>
where K: Clone + PartialEq + Ord, V: Clone,

pub fn try_from_iter( it: impl IntoIterator<Item = (Vec<K>, V)>, ) -> Result<Self, &'static str>

Construct a new Trie from key-value pairs.

Will panic if there are any key collisions or if there are any sequences that nest under a prefix that is already required to hold a value

pub fn merge(self, other: Self) -> Result<Self, &'static str>

Merge two Tries.

If the resulting Trie would be invalid to construct directly, an error is returned.

Consumes both inputs.

pub fn merge_overriding(self, other: Self) -> Result<Self, &'static str>

Merge two Tries preferring keys from other in the case of collisions.

If the resulting Trie would be invalid to construct directly, an error is returned.

Consumes both inputs.

pub fn get<'a>(&'a self, key: &[K]) -> QueryResult<'a, V>

Query this Trie for a given key or key prefix

If the key maps to a leaf then the value is returned, if it maps to a sub-trie then Partial is returned to denote that the given key is a parent of one or more values. If the key is not found within the Trie then Missing is returned.

pub fn get_exact<'a>(&'a self, key: &[K]) -> Option<&'a V>

Query this Trie for a given key or key prefix requiring the key to match exactly.

If the key maps to a leaf then the Some(value) is returned, otherwise None.

pub fn len(&self) -> usize

The number of leaf values in this Trie

pub fn is_empty(&self) -> bool

Whether this Trie is empty

Source

impl<V> Trie<char, V>
where V: Clone,

pub fn from_str_keys(pairs: Vec<(&str, V)>) -> Result<Self, &'static str>

Construct a new Trie with char internal keys from string keys.

pub fn get_str<'a>(&'a self, key: &str) -> QueryResult<'a, V>

Query this Trie using a string key.

Both full and partial matches are possible.

pub fn get_str_exact<'a>(&'a self, key: &str) -> Option<&'a V>

Query this Trie using a string key.

Only fll matches will be returned.