Sam style dot manipulation
See http://sam.cat-v.org/ for details on how sam works, particularly http://doc.cat-v.org/plan_9/4th_edition/papers/sam/ which is the original paper where Rob Pike lays out how the editor works.
All indexing is 0-based when working with the contents of a specific buffer. Converting to 1-based indices for the terminal is exclusively handled in the rendering logic.
Structs
- Cur
- Range
- A Range is a closed interval [start, end] that includes both the starting cursor and the ending cursor.
Enums
- Dot
- A Dot represents the currently selected contents of a Buffer.
- Text
Object - A vim-like text object which can be used to manipulate the current Dot in a Buffer