pub type DefaultMapping<K, V> = fn(&K) -> Option<V>;Expand description
A default handler for mapping a single length key to an Option<V>.
This is used to avoid having to specify large numbers of single length keys that should all be handled in a similar way.