The ad user interface
Structs
- Generic
Tui - Layout
- Layout is a screen layout of the windows available for displaying buffer content to the user. The available screen space is split into a number of columns each containing a vertical stack of windows.
Enums
- Border
- A border that can be dragged to resize
- State
Change - Sent by the Editor to a UserInterface when internal state has changed in such a way that a UI update may be required.
Constants
- SCRATCH_
ID - The reserved ID for the scratch buffer. If we ever collide with this when creating a normal buffer then the user is doing something very strange…
Traits
- User
Interface - Something that can be used as a user interface